@@ -197,11 +197,48 @@ static PyObject* pyalpm_db_readgrp(PyObject* rawself, PyObject* args) {
   return _pyobject_from_pmgrp(grp);
 }
 
+static PyObject *pyalpm_db_update(PyObject *rawself, PyObject *args, PyObject *kwargs) {
+  AlpmDB* self = (AlpmDB*)rawself;
+  char* keyword[] = {"force", NULL};
+  int ret;
+  PyObject *force;
+  if (!PyArg_ParseTupleAndKeywords(args, kwargs, "O!", keyword, &PyBool_Type, &force))
+    return NULL;
+
+  ret = alpm_db_update((force == Py_True), self->c_data);
+
+  switch(ret) {
+  case -1:
+    RET_ERR("unable to update database", NULL);
+  case 0:
+    Py_RETURN_TRUE;
+  case 1:
+    Py_RETURN_FALSE;
+  default:
+    RET_ERR("invalid return code from alpm_db_update()", NULL);
+  }
+}
+
+static PyObject* pyalpm_db_search(PyObject *rawself, PyObject *args) {
+  AlpmDB* self = (AlpmDB *)rawself;
+  alpm_list_t* rawargs;
+  alpm_list_t* result;
+  int ok = pylist_string_to_alpmlist(args, &rawargs);
+  if (ok == -1) return NULL;
+
+  result = alpm_db_search(self->c_data, rawargs);
+  return alpmlist_to_pylist(result, pyalpm_package_from_pmpkg);
+}
+
 static struct PyMethodDef db_methods[] = {
   { "get_pkg", pyalpm_db_get_pkg, METH_VARARGS,
     "get a package by name\n"
     "args: a package name (string)\n"
     "returns: a Package object or None if not found" },
+  { "search", pyalpm_db_search, METH_VARARGS,
+    "search for packages matching a list of regexps\n"
+    "args: a variable number of regexps (strings)\n"
+    "returns: packages matching all these regexps" },
   { "read_grp", pyalpm_db_readgrp, METH_VARARGS,
     "get contents of a group\n"
     "args: a group name (string)\n"
@@ -210,6 +247,10 @@ static struct PyMethodDef db_methods[] = {
     "set install reason for a package\n"
     "args: a package name (string), a reason (PKG_REASON_DEPEND, PKG_REASON_EXPLICIT)\n"
     "returns: None" },
+  { "update", (PyCFunction)pyalpm_db_update, METH_VARARGS | METH_KEYWORDS,
+    "update a database from its url attribute\n"
+    "args: force (update even if DB is up to date, boolean)\n"
+    "returns: True if an update has been done" },
   { NULL },
 };
 
